@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2012 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
@@ -6,13 +7,6 @@
 
 import __builtin__
 
-_dummy_gettext = lambda value: value
-_dummy_ngettext = lambda v1, v2, count: (count == 1) and v1 or v2
-__builtin__.__dict__["_"] = _dummy_gettext
-__builtin__.__dict__["Q_"] = _dummy_gettext
-__builtin__.__dict__["N_"] = _dummy_gettext
-__builtin__.__dict__["ngettext"] = _dummy_ngettext
-
 import gettext
 import locale
 import os
@@ -22,16 +16,21 @@ import warnings
 import quodlibet.const
 import quodlibet.util
 
-from quodlibet.util import load_library
+from quodlibet.util import set_process_title
 from quodlibet.util.path import mkdir, unexpand
-from quodlibet.util.i18n import GlibTranslations
+from quodlibet.util.i18n import GlibTranslations, set_i18n_envvars, \
+    fixup_i18n_envvars
 from quodlibet.util.dprint import print_, print_d, print_w, print_e
+from quodlibet import const
 from quodlibet.const import MinVersions, Version
 
 PLUGIN_DIRS = ["editing", "events", "playorder", "songsmenu", "playlist",
                "gstreamer", "covers"]
 
 
+GlibTranslations().install(unicode=True)
+
+
 class Application(object):
     """A main application class for controlling the application as a whole
     and accessing sub-modules.
@@ -49,6 +48,14 @@ class Application(object):
     library = None
     player = None
 
+    cover_manager = None
+
+    name = None
+    """The application name e.g. 'Quod Libet'"""
+
+    id = None
+    """The application ID e.g. 'quodlibet'"""
+
     @property
     def librarian(self):
         return self.library.librarian
@@ -88,7 +95,15 @@ class Application(object):
 app = Application()
 
 
-def fix_gst_leaks():
+def is_release():
+    """Returns whether the running version is a stable release or under
+    development.
+    """
+
+    return const.VERSION_TUPLE[-1] != -1
+
+
+def _fix_gst_leaks():
     """gst_element_add_pad and gst_bin_add are wrongly annotated and lead
     to PyGObject refing the passed element.
 
@@ -124,7 +139,9 @@ def fix_gst_leaks():
         Gst.Element.add_pad = do_wrap(Gst.Element.add_pad)
 
 
-def _gtk_init(icon=None):
+def _gtk_init():
+    """Call before using Gtk/Gdk"""
+
     import gi
 
     # make sure GdkX11 doesn't get used under Windows
@@ -147,7 +164,7 @@ def _gtk_init(icon=None):
     gi.require_version("GdkPixbuf", "2.0")
     gi.require_version("Gio", "2.0")
 
-    from gi.repository import Gtk, GObject, GLib, Gdk, GdkPixbuf
+    from gi.repository import Gtk, GObject, Gdk, GdkPixbuf
 
     # add Gtk.TreePath.__getitem__/__len__ for PyGObject 3.2
     try:
@@ -189,6 +206,16 @@ def _gtk_init(icon=None):
         'ignore', '.*Stock items are deprecated.*', Warning)
     warnings.filterwarnings(
         'ignore', '.*:use-stock.*', Warning)
+    warnings.filterwarnings(
+        'ignore', '.*The property GtkAlignment:[^\s]+ is deprecated.*',
+        Warning)
+
+    # Newer glib is noisy regarding deprecated signals/properties
+    # even with stable releases.
+    if is_release():
+        warnings.filterwarnings(
+            'ignore', '.* It will be removed in a future version.',
+            Warning)
 
     settings = Gtk.Settings.get_default()
     with warnings.catch_warnings():
@@ -247,34 +274,6 @@ def _gtk_init(icon=None):
     # https://bugzilla.gnome.org/show_bug.cgi?id=708676
     warnings.filterwarnings('ignore', '.*g_value_get_int.*', Warning)
 
-    # We don't want python-gst, it changes API..
-    assert "gi.overrides.Gst" not in sys.modules
-    sys.modules["gi.overrides.Gst"] = None
-
-    # We don't depend on Gst overrides, so make sure it's initialized.
-    try:
-        gi.require_version("Gst", "1.0")
-        from gi.repository import Gst
-    except (ValueError, ImportError):
-        pass
-    else:
-        if not Gst.is_initialized():
-            try:
-                ok, argv = Gst.init_check(sys.argv)
-            except GLib.GError:
-                print_e("Failed to initialize GStreamer")
-                # Uninited Gst segfaults: make sure no one can use it
-                sys.modules["gi.repository.Gst"] = None
-            else:
-                sys.argv = argv
-
-                # monkey patching ahead
-                fix_gst_leaks()
-
-                # https://bugzilla.gnome.org/show_bug.cgi?id=710447
-                import threading
-                threading.Thread(target=lambda: None).start()
-
     # blacklist some modules, simply loading can cause segfaults
     sys.modules["gtk"] = None
     sys.modules["gpod"] = None
@@ -286,14 +285,72 @@ def _gtk_init(icon=None):
     if pygobject_version < (3, 9):
         GObject.threads_init()
 
-    theme = Gtk.IconTheme.get_default()
-    theme.append_search_path(quodlibet.const.IMAGEDIR)
 
-    if icon:
-        Gtk.Window.set_default_icon_name(icon)
+def _gst_init():
+    """Call once before importing GStreamer"""
+
+    assert "gi.repository.Gst" not in sys.modules
+
+    import gi
+
+    # We don't want python-gst, it changes API..
+    assert "gi.overrides.Gst" not in sys.modules
+    sys.modules["gi.overrides.Gst"] = None
+
+    # blacklist some modules, simply loading can cause segfaults
+    sys.modules["gst"] = None
+
+    # We don't depend on Gst overrides, so make sure it's initialized.
+    try:
+        gi.require_version("Gst", "1.0")
+        from gi.repository import Gst
+    except (ValueError, ImportError):
+        return
+
+    if Gst.is_initialized():
+        return
+
+    from gi.repository import GLib
+
+    try:
+        ok, argv = Gst.init_check(sys.argv)
+    except GLib.GError:
+        print_e("Failed to initialize GStreamer")
+        # Uninited Gst segfaults: make sure no one can use it
+        sys.modules["gi.repository.Gst"] = None
+    else:
+        sys.argv = argv
+
+        # monkey patching ahead
+        _fix_gst_leaks()
+
+        # https://bugzilla.gnome.org/show_bug.cgi?id=710447
+        import threading
+        threading.Thread(target=lambda: None).start()
+
+
+def _gtk_icons_init(theme_search_path, default_icon_name=None):
+    """Register a local fallback icon theme containing our own icons.
+
+    `default_icon_name` is the icon name used for all windows if nothing
+    else is specified.
+    """
+
+    from gi.repository import Gtk
+
+    theme = Gtk.IconTheme.get_default()
+
+    assert os.path.exists(theme_search_path)
+    theme.append_search_path(theme_search_path)
+
+    if default_icon_name is not None:
+        assert theme.has_icon(default_icon_name)
+        Gtk.Window.set_default_icon_name(default_icon_name)
 
 
 def _dbus_init():
+    """Setup dbus mainloop integration. Call before using dbus"""
+
     try:
         from dbus.mainloop.glib import DBusGMainLoop, threads_init
     except ImportError:
@@ -308,19 +365,23 @@ def _dbus_init():
 
 
 def _gettext_init():
+    """Call before using gettext helpers"""
+
+    # set by tests
+    if "QUODLIBET_NO_TRANS" in os.environ:
+        return
+
+    set_i18n_envvars()
+    fixup_i18n_envvars()
+
+    print_d("LANGUAGE: %r" % os.environ.get("LANGUAGE"))
+    print_d("LANG: %r" % os.environ.get("LANG"))
+
     try:
         locale.setlocale(locale.LC_ALL, '')
     except locale.Error:
         pass
 
-    if os.name == "nt":
-        import ctypes
-        k32 = ctypes.windll.kernel32
-        langs = filter(None, map(locale.windows_locale.get,
-                                 [k32.GetUserDefaultUILanguage(),
-                                  k32.GetSystemDefaultUILanguage()]))
-        os.environ.setdefault('LANG', ":".join(langs))
-
     # Use the locale dir in ../build/share/locale if there is one
     localedir = os.path.dirname(quodlibet.const.BASEDIR)
     localedir = os.path.join(localedir, "build", "share", "locale")
@@ -343,23 +404,8 @@ def _gettext_init():
     else:
         print_d("Translations loaded: %r" % unexpand(t.path))
 
-    t.install(unicode=True)
-
-
-def set_process_title(title):
-    """Sets process name as visible in ps or top. Requires ctypes libc
-    and is almost certainly *nix-only. See issue 736"""
-
-    if os.name == "nt":
-        return
-
-    try:
-        libc = load_library(["libc.so.6", "c"])[0]
-        # 15 = PR_SET_NAME, apparently
-        libc.prctl(15, title, 0, 0, 0)
-    except (OSError, AttributeError):
-        print_d("Couldn't find module libc.so.6 (ctypes). "
-                "Not setting process title.")
+    debug_text = os.environ.get("QUODLIBET_TEST_TRANS")
+    t.install(unicode=True, debug_text=debug_text)
 
 
 def _python_init():
@@ -367,7 +413,8 @@ def _python_init():
     import sys
     if sys.version_info < MinVersions.PYTHON:
         actual = Version(sys.version_info[:3])
-        print_w("Python %s required. %s found." % (MinVersions.PYTHON, actual))
+        raise ImportError("Python %s required. %s found." %
+                          (MinVersions.PYTHON, actual))
 
     # some code depends on utf-8 default encoding (pygtk used to set it)
     reload(sys)
@@ -378,48 +425,36 @@ def _python_init():
     __builtin__.__dict__["print_e"] = print_e
     __builtin__.__dict__["print_w"] = print_w
 
-del(_dummy_gettext)
-del(_dummy_ngettext)
-
 _python_init()
 _gettext_init()
 
 
-def init(library=None, icon=None, title=None, name=None):
+def init(icon=None, proc_title=None, name=None):
+    global quodlibet
+
     print_d("Entering quodlibet.init")
 
-    _gtk_init(icon)
+    _gtk_init()
+    _gtk_icons_init(quodlibet.const.IMAGEDIR, icon)
+    _gst_init()
     _dbus_init()
+    _init_debug()
 
     from gi.repository import GLib
 
-    if title:
-        GLib.set_prgname(title)
-        set_process_title(title)
+    if proc_title:
+        GLib.set_prgname(proc_title)
+        set_process_title(proc_title)
         # Issue 736 - set after main loop has started (gtk seems to reset it)
-        GLib.idle_add(set_process_title, title)
+        GLib.idle_add(set_process_title, proc_title)
 
     if name:
         GLib.set_application_name(name)
 
-    # We already imported this, but Python is dumb and thinks we're rebinding
-    # a local when we import it later.
-    import quodlibet.util
     mkdir(quodlibet.const.USERDIR, 0750)
 
-    if library:
-        print_d("Initializing main library (%s)" % (
-            quodlibet.util.path.unexpand(library)))
-
-    import quodlibet.library
-    library = quodlibet.library.init(library)
-
-    _init_debug()
-
     print_d("Finished initialization.")
 
-    return library
-
 
 def init_plugins(no_plugins=False):
     print_d("Starting plugin manager")
@@ -469,7 +504,8 @@ def enable_periodic_save(save_library):
 
     def periodic_library_save():
         while 1:
-            quodlibet.library.save()
+            # max every 15 minutes
+            quodlibet.library.save(save_period=15 * 60)
             yield
 
     copool.add(periodic_library_save, timeout=timeout)
@@ -560,13 +596,16 @@ def _init_osx(window):
     delegate = Delegate.alloc().init()
     delegate.retain()
     shared_app.setDelegate_(delegate)
-    window.connect(
-        "delete-event", lambda window, event: window.hide() or True)
+
+    # QL shouldn't exit on window close, EF should
+    if window.get_osx_is_persistent():
+        window.connect(
+            "delete-event", lambda window, event: window.hide() or True)
 
 
 def main(window, before_quit=None):
     print_d("Entering quodlibet.main")
-    from gi.repository import Gtk
+    from gi.repository import Gtk, Gdk
 
     def quit_gtk(window):
 
@@ -606,7 +645,9 @@ def main(window, before_quit=None):
     if sys.platform == "darwin":
         _init_osx(window)
 
-    window.show_maybe()
+    if not window.show_maybe():
+        # if we don't show a window, startup isn't completed, so call manually
+        Gdk.notify_startup_complete()
 
     Gtk.main()
     print_d("Gtk.main() done.")
