@@ -26,14 +26,11 @@ class Version(tuple):
 class MinVersions(object):
     """Dependency requirements for Quod Libet / Ex Falso"""
     PYTHON = Version(2, 7)
-    MUTAGEN = Version(1, 14)
+    MUTAGEN = Version(1, 22)
 
-VERSION_TUPLE = Version(3, 3, 1)
+VERSION_TUPLE = Version(3, 4, 1)
 VERSION = str(VERSION_TUPLE)
 
-PROCESS_TITLE_QL = "quodlibet"
-PROCESS_TITLE_EF = "exfalso"
-
 if os.name == "nt":
     file_path = __file__.decode(sys.getfilesystemencoding())
     BASEDIR = os.path.dirname(os.path.realpath(file_path))
@@ -69,29 +66,32 @@ CURRENT = os.path.join(USERDIR, "current")
 LIBRARY = os.path.join(USERDIR, "songs")
 LOGDIR = os.path.join(USERDIR, "logs")
 
-# Don't bother saving the library more often than this
-LIBRARY_SAVE_PERIOD_SECONDS = 15 * 60
-
 # entry point for the user guide / wiki
-BRANCH_NAME = "quodlibet-3.3"
+BRANCH_NAME = "quodlibet-3.4"
 DOCS_BASE_URL = "https://quodlibet.readthedocs.org/en/%s"
 DOCS_LATEST = DOCS_BASE_URL % "latest"
-DOCS_BASE_URL %= BRANCH_NAME if BRANCH_NAME != "default" else "latest"
+DOCS_BASE_URL %= BRANCH_NAME if BRANCH_NAME != "master" else "latest"
 ONLINE_HELP = DOCS_BASE_URL + "/guide/index.html"
 SEARCH_HELP = DOCS_BASE_URL + "/guide/searching.html"
 
-# about dialog, --version etc.
-WEBSITE = "http://code.google.com/p/quodlibet"
-COPYRIGHT = """\
-Copyright © 2004-2014 Joe Wreschnig, Michael Urman, Iñigo Serna,
-Steven Robertson, Christoph Reiter, Nick Boultbee, ..."""
-
 # Email used as default for reading/saving per-user data in tags, etc.
 EMAIL = environ.get("EMAIL", "quodlibet@lists.sacredchao.net")
 
 # Displayed as registered / help email address
 SUPPORT_EMAIL = "quod-libet-development@googlegroups.com"
 
+MAIN_AUTHORS = """\
+Joe Wreschnig
+Michael Urman
+Iñigo Serna
+Steven Robertson
+Christoph Reiter
+Nick Boultbee""".split("\n")
+
+# about dialog, --version etc.
+WEBSITE = "https://quodlibet.readthedocs.org/"
+COPYRIGHT = """Copyright © 2004-2015 %s...""" % ", ".join(MAIN_AUTHORS)
+
 AUTHORS = sorted("""\
 Alexandre Passos
 Alexey Bobyakov
