@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2014 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
@@ -10,9 +11,8 @@ from quodlibet.plugins.playlist import PlaylistPlugin
 class Shuffle(PlaylistPlugin):
     PLUGIN_ID = "Shuffle Playlist"
     PLUGIN_NAME = _("Shuffle Playlist")
-    PLUGIN_DESC = _("Randomly shuffles a playlist")
+    PLUGIN_DESC = _("Randomly shuffles a playlist.")
     PLUGIN_ICON = 'gtk-execute'
-    PLUGIN_VERSION = "1.0"
 
     def plugin_playlist(self, playlist):
         playlist.shuffle()
