@@ -23,20 +23,19 @@ from cStringIO import StringIO
 from xml.dom import minidom
 
 from gi.repository import Gtk, Pango, GLib, Gdk, GdkPixbuf
-from quodlibet.parse._pattern import ArbitraryExtensionFileFromPattern
+from quodlibet.pattern import ArbitraryExtensionFileFromPattern
 from quodlibet.plugins import PluginConfigMixin
 from quodlibet.util import format_size, print_exc
 from quodlibet.util.dprint import print_d
 
 from quodlibet import util, qltk, print_w, app
 from quodlibet.qltk.msg import ConfirmFileReplace
-from quodlibet.qltk.x import Paned
+from quodlibet.qltk.x import Paned, Align
 from quodlibet.qltk.views import AllTreeView
 from quodlibet.qltk.image import (set_renderer_from_pbosf, get_scale_factor,
-    get_pbosf_for_pixbuf, set_image_from_pbosf)
+    get_pbosf_for_pixbuf, set_image_from_pbosf, scale, add_border_widget)
 from quodlibet.plugins.songsmenu import SongsMenuPlugin
 from quodlibet.util.path import iscommand
-from quodlibet.util import thumbnails
 
 
 USER_AGENT = "Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.13) " \
@@ -262,8 +261,8 @@ class CoverArea(Gtk.VBox, PluginConfigMixin):
             else:
                 fn_list.append("<artist> - <album>.jpg")
         else:
-            print_w("No album for \"%s\". Could be difficult finding art..." %
-                    song("~filename"))
+            print_w(u"No album for \"%s\". Could be difficult "
+                    u"finding art…" % song("~filename"))
             title = song("title")
             if title and artist:
                 fn_list.append("<artist> - <title>.jpg")
@@ -303,8 +302,7 @@ class CoverArea(Gtk.VBox, PluginConfigMixin):
         bbox.pack_start(self.button, True, True, 0)
         bbox.pack_start(close_button, True, True, 0)
 
-        bb_align = Gtk.Alignment.new(0, 1, 1, 0)
-        bb_align.set_property('right-padding', 6)
+        bb_align = Align(valign=Gtk.Align.END, right=6)
         bb_align.add(bbox)
 
         main_hbox = Gtk.HBox()
@@ -362,7 +360,7 @@ class CoverArea(Gtk.VBox, PluginConfigMixin):
                 except:
                     pass
 
-            app.window.emit("artwork-changed", [self.song])
+            app.cover_manager.cover_changed([self.song])
 
         self.main_win.destroy()
 
@@ -395,7 +393,7 @@ class CoverArea(Gtk.VBox, PluginConfigMixin):
             height = alloc.height
             scale_factor = get_scale_factor(self)
             boundary = (width * scale_factor, height * scale_factor)
-            pixbuf = thumbnails.scale(pixbuf, boundary, scale_up=False)
+            pixbuf = scale(pixbuf, boundary, scale_up=False)
             pbosf = get_pbosf_for_pixbuf(self, pixbuf)
 
         set_image_from_pbosf(self.image, pbosf)
@@ -561,11 +559,14 @@ class AlbumArtWindow(qltk.Window, PluginConfigMixin):
             esc = escape_data
 
             txt = '<b><i>%s</i></b>' % esc(cover['name'])
-            txt += _('\n<small>from <i>%s</i></small>') % esc(cover['source'])
+            txt += "\n<small>%s</small>" % (
+                _('from %(source)s') % {
+                    "source": util.italic(esc(cover['source']))})
             if 'resolution' in cover:
-                txt += _('\nResolution: <i>%s</i>') % esc(cover['resolution'])
+                txt += "\n" + _('Resolution: %s') % util.italic(
+                    esc(cover['resolution']))
             if 'size' in cover:
-                txt += _('\nSize: <i>%s</i>') % esc(cover['size'])
+                txt += "\n" + _('Size: %s') % util.italic(esc(cover['size']))
 
             cell.markup = txt
             cell.set_property('markup', cell.markup)
@@ -639,7 +640,7 @@ class AlbumArtWindow(qltk.Window, PluginConfigMixin):
         self.search_button.set_sensitive(False)
 
         self.progress.set_fraction(0)
-        self.progress.set_text(_('Searching...'))
+        self.progress.set_text(_(u'Searching…'))
         self.progress.show()
 
         self.liststore.clear()
@@ -684,8 +685,7 @@ class AlbumArtWindow(qltk.Window, PluginConfigMixin):
             size = self.THUMB_SIZE * scale_factor - scale_factor * 2
             pixbuf = pbloader.get_pixbuf().scale_simple(size, size,
                 GdkPixbuf.InterpType.BILINEAR)
-            pixbuf = thumbnails.add_border_widget(
-                pixbuf, self, None, round=True)
+            pixbuf = add_border_widget(pixbuf, self, None, round=True)
             thumb = get_pbosf_for_pixbuf(self, pixbuf)
         except (GLib.GError, IOError):
             pass
@@ -817,9 +817,8 @@ class DownloadAlbumArt(SongsMenuPlugin, PluginConfigMixin):
 
     PLUGIN_ID = 'Download Album Art'
     PLUGIN_NAME = _('Download Album Art')
-    PLUGIN_DESC = _('Download album covers from various websites')
+    PLUGIN_DESC = _('Downloads album covers from various websites.')
     PLUGIN_ICON = Gtk.STOCK_FIND
-    PLUGIN_VERSION = '0.5.2'
     CONFIG_SECTION = PLUGIN_CONFIG_SECTION
 
     @classmethod
