@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman
 #           2012 Christoph Reiter
 #
@@ -26,8 +27,9 @@ def init():
 
     import mutagen
     if mutagen.version < MinVersions.MUTAGEN:
-        print_w("Mutagen %s required. %s found."
-                % (MinVersions.MUTAGEN, mutagen.version_string))
+        raise ImportError(
+            "Mutagen %s required. %s found." %
+            (MinVersions.MUTAGEN, mutagen.version_string))
 
     base = os.path.dirname(__file__)
     load_pyc = os.name == 'nt'
@@ -58,6 +60,11 @@ def init():
     modules.sort()
     names.sort()
 
+    # This can be used for the quodlibet.desktop file
+    desktop_mime_types = "MimeType=" + \
+        ";".join(sorted(set([m.split(";")[0] for m in mimes]))) + ";"
+    print_d(desktop_mime_types)
+
     if not _infos:
         raise SystemExit("No formats found!")
 
