@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2004-2011 Joe Wreschnig, Michael Urman, Steven Robertson,
 #           2011-2014 Christoph Reiter
 #
@@ -18,7 +19,8 @@ from quodlibet import const
 from quodlibet import config
 from quodlibet import util
 
-from quodlibet.util import fver, sanitize_tags, MainRunner, MainRunnerError
+from quodlibet.util import fver, sanitize_tags, MainRunner, MainRunnerError, \
+    MainRunnerAbortedError, MainRunnerTimeoutError
 from quodlibet.player import PlayerError
 from quodlibet.player._base import BasePlayer
 from quodlibet.qltk.notif import Task
@@ -172,6 +174,7 @@ class GStreamerPlayer(BasePlayer, GStreamerPluginHandler):
         self._pipeline_desc = None
         self._lib_id = librarian.connect("changed", self.__songs_changed)
         self._active_seeks = []
+        self._active_error = False
         self._runner = MainRunner()
 
     def __songs_changed(self, librarian, songs):
@@ -218,6 +221,9 @@ class GStreamerPlayer(BasePlayer, GStreamerPluginHandler):
         if self.bin:
             return True
 
+        # reset error state
+        self.error = False
+
         pipeline = config.get("player", "gst_pipeline")
         try:
             pipeline, self._pipeline_desc = GStreamerSink(pipeline)
@@ -476,43 +482,64 @@ class GStreamerPlayer(BasePlayer, GStreamerPluginHandler):
                 GstPbutils.InstallPluginsReturn.INTERNAL_FAILURE):
             self._error(PlayerError(title, error_details))
 
-    def __about_to_finish(self, pipeline):
-        print_d("About to finish")
+    def __about_to_finish_sync(self):
+        """Returns a tuple (ok, next_song). ok is True if the next song
+        should be set.
+        """
+
+        print_d("About to finish (sync)")
 
         # Chained oggs falsely trigger a gapless transition.
         # At least for radio streams we can safely ignore it because
         # transitions don't occur there.
-        # https://code.google.com/p/quodlibet/issues/detail?id=1454
+        # https://github.com/quodlibet/quodlibet/issues/1454
         # https://bugzilla.gnome.org/show_bug.cgi?id=695474
         if self.song.multisong:
             print_d("multisong: ignore about to finish")
-            return
+            return (False, None)
 
         if config.getboolean("player", "gst_disable_gapless"):
             print_d("Gapless disabled")
-            return
+            return (False, None)
 
         # this can trigger twice, see issue 987
         if self._in_gapless_transition:
-            return
+            return (False, None)
         self._in_gapless_transition = True
 
-        def change_in_main_loop(source):
-            print_d("Select next song in mainloop..")
-            source.next_ended()
-            print_d("..done.")
+        print_d("Select next song in mainloop..")
+        self._source.next_ended()
+        print_d("..done.")
+
+        return (True, self._source.current)
+
+    def __about_to_finish(self, playbin):
+        print_d("About to finish (async)")
 
         try:
-            self._runner.call(change_in_main_loop, self._source,
-                              priority=GLib.PRIORITY_HIGH)
+            ok, song = self._runner.call(self.__about_to_finish_sync,
+                                         priority=GLib.PRIORITY_HIGH,
+                                         timeout=0.5)
+        except MainRunnerTimeoutError as e:
+            # Due to some locks being held during this signal we can get
+            # into a deadlock when a seek or state change event happens
+            # in the mainloop before our function gets scheduled.
+            # In this case abort and do nothing, which results
+            # in a non-gapless transition.
+            print_d("About to finish (async): %s" % e)
+            return
+        except MainRunnerAbortedError:
+            print_d("About to finish (async): %s" % e)
+            return
         except MainRunnerError:
             util.print_exc()
+            return
 
-        song = self._source.current
-        bin = self.bin
-
-        if song and bin:
-            bin.set_property('uri', song("~uri"))
+        if ok:
+            print_d("About to finish (async): setting uri")
+            uri = song("~uri") if song is not None else None
+            playbin.set_property('uri', uri)
+        print_d("About to finish (async): done")
 
     def stop(self):
         super(GStreamerPlayer, self).stop()
@@ -551,22 +578,28 @@ class GStreamerPlayer(BasePlayer, GStreamerPluginHandler):
                 self._last_position = p
         return p
 
-    def _set_paused(self, paused):
+    @property
+    def paused(self):
+        return self._paused
+
+    @paused.setter
+    def paused(self, paused):
         if paused == self._paused:
             return
-        self._paused = paused
 
-        if not self.song:
-            if paused:
-                # Something wants us to pause between songs, or when
-                # we've got no song playing (probably StopAfterMenu).
-                self.emit('paused')
-                self.__destroy_pipeline()
+        self._paused = paused
+        self.emit((paused and 'paused') or 'unpaused')
+        # in case a signal handler changed the paused state, abort this
+        if self._paused != paused:
             return
 
         if paused:
             if self.bin:
-                if self.song.is_file:
+                if not self.song:
+                    # Something wants us to pause between songs, or when
+                    # we've got no song playing (probably StopAfterMenu).
+                    self.__destroy_pipeline()
+                elif self.song.is_file:
                     # fast path
                     self.bin.set_state(Gst.State.PAUSED)
                 else:
@@ -581,17 +614,8 @@ class GStreamerPlayer(BasePlayer, GStreamerPluginHandler):
                         # destroy so that we rebuffer on resume
                         self.__destroy_pipeline()
         else:
-            if self.bin:
+            if self.song and self.__init_pipeline():
                 self.bin.set_state(Gst.State.PLAYING)
-            else:
-                if self.__init_pipeline():
-                    self.bin.set_state(Gst.State.PLAYING)
-
-        self.emit((paused and 'paused') or 'unpaused')
-
-    def _get_paused(self):
-        return self._paused
-    paused = property(_get_paused, _set_paused)
 
     def _error(self, player_error):
         """Destroy the pipeline and set the error state.
@@ -600,8 +624,9 @@ class GStreamerPlayer(BasePlayer, GStreamerPluginHandler):
         """
 
         # prevent recursive errors
-        if self.error:
+        if self._active_error:
             return
+        self._active_error = True
 
         self.__destroy_pipeline()
         self.error = True
@@ -609,6 +634,7 @@ class GStreamerPlayer(BasePlayer, GStreamerPluginHandler):
 
         print_w(unicode(player_error))
         self.emit('error', self.song, player_error)
+        self._active_error = False
 
     def seek(self, pos):
         """Seek to a position in the song, in milliseconds."""
@@ -657,9 +683,6 @@ class GStreamerPlayer(BasePlayer, GStreamerPluginHandler):
             self.emit('song-ended', info, stopped)
         self.emit('song-ended', song, stopped)
 
-        # reset error state
-        self.error = False
-
         current = self._source.current if next_song is None else next_song
 
         # Then, set up the next song.
