@@ -12,11 +12,13 @@ from gi.repository import Gtk, Pango
 from quodlibet import const
 from quodlibet import qltk
 from quodlibet import util
+from quodlibet import app
 
 from quodlibet.qltk.bookmarks import EditBookmarksPane
 from quodlibet.qltk.cover import CoverImage
 from quodlibet.qltk.lyrics import LyricsPane
 from quodlibet.qltk.window import Window, PersistentWindowMixin
+from quodlibet.qltk.x import Align
 from quodlibet.util import tag, connect_destroy
 from quodlibet.util.tags import readable
 from quodlibet.util.path import fsdecode, filesize, unexpand
@@ -35,8 +37,7 @@ def Frame(name, widget):
     l = Gtk.Label()
     l.set_markup("<u><b>%s</b></u>" % name)
     f.set_label_widget(l)
-    a = Gtk.Alignment.new(xalign=0, yalign=0, xscale=1, yscale=1)
-    a.set_padding(3, 0, 12, 0)
+    a = Align(top=3, left=12)
     f.add(a)
     a.add(widget)
     return f
@@ -475,7 +476,9 @@ class OneArtist(qltk.Notebook):
                 return "%s (%s)" % (album, date[:4])
             else:
                 return album
-        covers = [(a, s.find_cover(), s) for d, s, a in albums]
+
+        get_cover = app.cover_manager.get_cover
+        covers = [(a, get_cover(s), s) for d, s, a in albums]
         albums = map(format, albums)
         if noalbum:
             albums.append(ngettext("%d song with no album",
@@ -586,6 +589,7 @@ class Information(Window, PersistentWindowMixin):
     def __init__(self, library, songs, parent=None):
         super(Information, self).__init__(dialog=False)
         self.set_default_size(400, 400)
+        self.set_transient_for(qltk.get_top_parent(parent))
         self.enable_window_tracking("quodlibet_information")
         if len(songs) > 1:
             connect_destroy(library, 'changed', self.__check_changed)
@@ -593,7 +597,6 @@ class Information(Window, PersistentWindowMixin):
             connect_destroy(library, 'removed', self.__check_removed)
         self.__songs = songs
         self.__update(library)
-        self.set_transient_for(qltk.get_top_parent(parent))
         self.get_child().show_all()
 
     def __check_changed(self, library, songs):
