@@ -18,14 +18,15 @@ from quodlibet import util
 from quodlibet import app
 from quodlibet.config import RATINGS
 
-from quodlibet.parse import Query
 from quodlibet.qltk.ccb import ConfigCheckButton as CCB
 from quodlibet.qltk.data_editors import MultiStringEditor
-from quodlibet.qltk.entry import ValidatingEntry, UndoEntry
+from quodlibet.qltk.entry import ValidatingEntry, UndoEntry, QueryValidator
 from quodlibet.qltk.scanbox import ScanBox
 from quodlibet.qltk.maskedbox import MaskedBox
 from quodlibet.qltk.songlist import SongList, get_columns
 from quodlibet.qltk.window import UniqueWindow
+from quodlibet.qltk.x import Button, Align
+from quodlibet.qltk import icons
 from quodlibet.util import copool
 from quodlibet.util.dprint import print_d
 from quodlibet.util.library import emit_signal, get_scan_dirs, scan_library
@@ -96,7 +97,8 @@ class PreferencesWindow(UniqueWindow):
             self.others = others = UndoEntry()
             others.set_sensitive(False)
             # Stock edit doesn't have ellipsis chars.
-            edit_button = Gtk.Button(label=_("_Edit..."), use_underline=True)
+            edit_button = Gtk.Button(
+                label=_(u"_Edit…"), use_underline=True)
             edit_button.connect("clicked", self.__config_cols)
             edit_button.set_tooltip_text(_("Add or remove additional column "
                                            "headers"))
@@ -217,7 +219,7 @@ class PreferencesWindow(UniqueWindow):
             hb = Gtk.HBox(spacing=6)
             l = Gtk.Label(label=_("_Global filter:"))
             l.set_use_underline(True)
-            e = ValidatingEntry(Query.is_valid_color)
+            e = ValidatingEntry(QueryValidator)
             e.set_text(config.get("browsers", "background"))
             e.connect('changed', self._entry, 'background', 'browsers')
             e.set_tooltip_text(_("Apply this query in addition to all others"))
@@ -227,7 +229,7 @@ class PreferencesWindow(UniqueWindow):
             vb.pack_start(hb, False, True, 0)
 
             # Translators: The heading of the preference group, no action
-            f = qltk.Frame(Q_("heading|Search"), child=vb)
+            f = qltk.Frame(C_("heading", "Search"), child=vb)
             self.pack_start(f, False, True, 0)
 
             # Ratings
@@ -292,7 +294,7 @@ class PreferencesWindow(UniqueWindow):
             config.set('albumart', name, entry.get_text())
 
         def __toggle_round_corners(self, *args):
-            qltk.redraw_all_toplevels(self)
+            qltk.redraw_all_toplevels()
 
         def __toggled_force_filename(self, cb, fn_entry):
             fn_entry.set_sensitive(cb.get_active())
@@ -361,11 +363,11 @@ class PreferencesWindow(UniqueWindow):
             table.attach(pre_label, 0, 1, 2, 3,
                          xoptions=Gtk.AttachOptions.FILL)
 
-            fb_align = Gtk.Alignment.new(0, 0.5, 0, 1)
+            fb_align = Align(halign=Gtk.Align.START)
             fb_align.add(fb_spin)
             table.attach(fb_align, 1, 2, 1, 2)
 
-            pre_align = Gtk.Alignment.new(0, 0.5, 0, 1)
+            pre_align = Align(halign=Gtk.Align.START)
             pre_align.add(pre_spin)
             table.attach(pre_align, 1, 2, 2, 3)
 
@@ -412,7 +414,7 @@ class PreferencesWindow(UniqueWindow):
                 if it is None:
                     return
                 RATINGS.default = model[it][0]
-                qltk.redraw_all_toplevels(self)
+                qltk.redraw_all_toplevels()
 
             def populate_default_rating_model(combo, num):
                 model = combo.get_model()
@@ -441,7 +443,7 @@ class PreferencesWindow(UniqueWindow):
             # Rating Scale
             model = Gtk.ListStore(int)
             scale_combo = Gtk.ComboBox(model=model)
-            scale_lab = Gtk.Label(label=_("Rating _Scale:"))
+            scale_lab = Gtk.Label(label=_("Rating _scale:"))
             scale_lab.set_use_underline(True)
             scale_lab.set_mnemonic_widget(scale_combo)
 
@@ -469,18 +471,16 @@ class PreferencesWindow(UniqueWindow):
             scale_combo.set_cell_data_func(cell, draw_rating_scale, None)
             scale_combo.connect('changed', rating_scale_changed, model)
 
-            default_align = Gtk.Alignment(xalign=0, xscale=0)
+            default_align = Align(halign=Gtk.Align.START)
             default_align.add(default_lab)
-            default_combo_align = Gtk.Alignment(xalign=0, xscale=0)
-            default_combo_align.add(default_combo)
-            scale_align = Gtk.Alignment(xalign=0, xscale=0)
+            scale_align = Align(halign=Gtk.Align.START)
             scale_align.add(scale_lab)
 
             grid = Gtk.Grid(column_spacing=6, row_spacing=6)
             grid.add(scale_align)
             grid.add(scale_combo)
             grid.attach(default_align, 0, 1, 1, 1)
-            grid.attach(default_combo_align, 1, 1, 1, 1)
+            grid.attach(default_combo, 1, 1, 1, 1)
             vb.pack_start(grid, False, False, 6)
 
             # Bayesian Factor
@@ -646,9 +646,19 @@ class PreferencesWindow(UniqueWindow):
         self.__notebook = notebook = qltk.Notebook()
         for Page in [self.SongList, self.Browsers, self.Player,
                      self.Library, self.Tagging]:
-            notebook.append_page(Page())
+            page = Page()
+            page.show()
+            notebook.append_page(page)
 
-        close = Gtk.Button(stock=Gtk.STOCK_CLOSE)
+        page_name = config.get("memory", "prefs_page", "")
+        self.set_page(page_name)
+
+        def on_switch_page(notebook, page, page_num):
+            config.set("memory", "prefs_page", page.name)
+
+        notebook.connect("switch-page", on_switch_page)
+
+        close = Button(_("_Close"), icons.WINDOW_CLOSE)
         connect_obj(close, 'clicked', lambda x: x.destroy(), self)
         button_box = Gtk.HButtonBox()
         button_box.set_layout(Gtk.ButtonBoxStyle.END)
